<?php

/**
 * @file
 * Contains \Drupal\cforge\Entity\NeighbourhoodRouteProvider.
 */

namespace Drupal\cforge\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Routing\EntityRouteProviderInterface;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Provides routes for the user entity.
 */
class NeighbourhoodRouteProvider implements EntityRouteProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function getRoutes(EntityTypeInterface $entity_type) {
    $route_collection = new RouteCollection();

    $route = (new Route('/admin/config/cforge/neighbourhoods'))
      ->setDefaults([
        '_entity_list' => 'cforge_neighbourhood',
        '_title' => 'Neighbourhoods',
      ])
      ->setRequirement('_permission', 'committee')
      ->setOption('_admin_route', TRUE);
    $route_collection->add('entity.cforge_neighbourhood.collection', $route);

    $route = (new Route('/admin/config/cforge/neighbourhoods/add'))
      ->setDefaults([
        '_entity_form' => 'cforge_neighbourhood.edit',
        '_title' => 'New neighbourhood',
      ])
      ->setRequirement('_entity_create_access', 'cforge_neighbourhood')
      ->setOption('_admin_route', TRUE);
    $route_collection->add('entity.cforge_neighbourhood.add_form', $route);

    $route = (new Route('/admin/config/cforge/neighbourhoods/{cforge_neighbourhood}'))
      ->setDefaults([
        '_entity_form' => 'cforge_neighbourhood.edit',
        '_title' => 'Editing neighbourhood',
      ])
      ->setRequirement('_permission', 'committee')
      ->setOption('_admin_route', TRUE);
    $route_collection->add('entity.cforge_neighbourhood.edit_form', $route);

    $route = (new Route('/admin/config/cforge/neighbourhoods/{cforge_neighbourhood}/delete'))
      ->setDefaults([
        '_entity_form' => 'cforge_neighbourhood.delete',
        '_title' => 'Delete neighbourhood',
      ])
      ->setRequirement('_permission', 'committee')
      ->setRequirement('_custom', '\Drupal\cforge\Access\NeighbourhoodDeleteAccess')
      ->setOption('_admin_route', TRUE);
    $route_collection->add('entity.cforge_neighbourhood.delete_form', $route);

    return $route_collection;
  }
}
