<?php

/**
 * @file
 * Contains \Drupal\cforge\Form\Settings.
 *
 */
namespace Drupal\cforge\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\Entity\EntityFormDisplay;

class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'cforge_settings';
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildform($form, $form_state);
    $config = $this->config('cforge.settings');
    $form['mail'] = [
      '#title' => $this->t('Mail'),
      '#type' => 'details',
      'mail_footer' => [
        '#title' => $this->t('Footer'),
        '#description' => $this->t('Appended to all mails sent by the site to members. HTML is allowed.'),
        '#type' => 'textarea',
        '#rows' => 4,
        '#default_value' => $config->get('mail_footer')
      ],
      //the broadcast settings would go here
      '#weight' => 2
    ];
    
    Self::buildLoginOptions($form);
    $form['login_options']['#weight'] = 3;
    
    $form['robots_protect'] = [
      '#title' => t('Conceal from search engines'),
      '#description' => t('Rewrites the robots.txt file'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('robots_protect', 0),
      '#weight' => 4
    ];
    $form['flat_menus'] = [
      '#title' => t('Enforce flat menus'),
      '#description' => t('Keep main menu and secondary menu flat'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('flat_menus', 0),
      '#weight' => 5
    ];
    
    return $form;
  }
  
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = $this->configFactory->getEditable('cforge.settings');
    $config
      ->set('mail_footer', $values['mail_footer'])
      ->set('neighbourhoods', trim($values['neighbourhoods']))
      ->set('robots_protect', $values['robots_protect'])
      ->set('flat_menus', $values['flat_menus'])
      ->save();
  }
  
  function getEditableConfigNames() {
    return ['cforge.settings'];
  }
  
  static function buildLoginOptions(&$form) {
    $form['login_options'] = [
      '#title' => t('Username & login options'),
      '#type' => 'details',
      'login' => [
        '#title' => t('Login with'),
        '#description' => t('Choosing fewer of these will reduce confusion.'),
        '#type' => 'checkboxes',
        '#options' => [
          'username' => t('Username'),
          'real_name' => t('Real name'),
          'code' => t('Some other ID, such as a membership code'),
          'email' => t('Email')
        ],
        '#default_value' => [//default_value can't be set for checkboxes
          'username' => 'username',
        ] + \Drupal::Config('cforge.settings')->get('login'),
        'username' => ['#disabled' => TRUE]
      ],
      'avatar' => [
        '#title' => t('Visible name'),
        '#description' => t("The user's name as it appears to other members.") .' '.
          t(
            'Use the following tokens: @tokens', 
            ['@tokens' => '[real_name], [code]']
          ),
        '#type' => 'textfield',
        '#placeholder' => '[real_name] ([code])',
        '#default_value' => \Drupal::Config('cforge.settings')->get('avatar')
      ]
    ];
    $form['#submit'][] = [
      '\Drupal\cforge\Form\Settings', 
      'submitLoginOptions'
    ];
  }
  
  /**
   * form submit callback, used here but also in HamletsConfigureForm as a setup option
   * @param type $form
   * @param type $form_state
   */
  static function submitLoginOptions($form, $form_state) {
    $login = $form_state->getValue('login');
    $avatar = $form_state->getValue('avatar');
    drupal_set_message('avatar '.strpos($avatar, '[code]'));
    //install and set up the alt_login module if needed
    $installer = \Drupal::service('module_installer');
    if (isset($login['code']) || strpos($avatar, '[code]') !== FALSE) {
      if (!\Drupal::moduleHandler()->moduleExists('alt_login')) {
        $installer->install(['alt_login']);
        //suppress the helpful messages created by installing
        drupal_get_messages('status', TRUE);
        drupal_set_message('alt_login module has been installed, but the field is empty for all users.');
        if ($display = EntityFormDisplay::load('user.user.admin')) {
          $config = [
            'type' => 'string_textfield',
            'weight' => 2,
            'settings' => [
              'size' => 12,
              'placeholder' => ''//would be great to configure this
            ]
          ];
          $display->setComponent('member_code', $config)->save();
        }
      }
    }
    else {
      $installer->uninstall(['alt_login']);
    }
    \Drupal::configFactory()->getEditable('cforge.settings')
      ->set('login', array_filter($login))
      ->set('avatar', $avatar)
      ->save();
  }
}
