<?php

/**
 * @file
 * Definition of Drupal\cforge\NeighbourhoodForm.
 */

namespace Drupal\cforge;

use Drupal\Core\Entity\EntityForm;
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormStateInterface;

class NeighbourhoodForm extends EntityForm {

  /**
   * Overrides Drupal\Core\Entity\EntityForm::form().
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $form['name'] = [
      '#type' => 'textfield',
      '#title' => t('Name of neighbourhood'),
      '#default_value' => $this->entity->label(),
      '#size' => 40,
      '#maxlength' => 64,
      '#required' => TRUE,
      '#weight' => 0,
    ];
    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $this->entity->id(),
      '#size' => 40,
      '#maxlength' => 64,
      '#required' => TRUE,
      '#disabled' => (bool)$this->entity->id(),
      '#weight' => 1,
      '#machine_name' => [
        'exists' => ['\Drupal\cforge\Entity\Neighbourhood', 'load'],
        'source' => ['name'],
      ]
    ];
    $form['uid'] = [
      '#title' => t('Coordinator'),
      '#description' => t("Point of contact for this neighbourhood"),
      '#type' => 'entity_autocomplete',
      '#target_type' => 'user',
      '#selection_handler' => 'default:user',
      '#selection_settings' => [
        'filter' => [
          'role' => ['trader']
        ]
      ],
      '#tags' => FALSE,
      '#default_value' => User::load($this->entity->uid)
    ];

    //@todo put the geo-polygon field
    $form['polygon'] = [
      '#type' => 'value',
      '#value' => $this->entity->polygon
    ];
    return $form;
  }

  /**
   * Overrides Drupal\Core\Entity\EntityForm::save().
   */
  public function save(array $form, FormStateInterface $form_state) {
    $status = $this->entity->save();
    if ($status == SAVED_UPDATED) {
      drupal_set_message(t('Neighbourhood %label has been updated.', ['%label' => $this->entity->label()]));
    }
    else {
      drupal_set_message(t('Neighbourhood %label has been added.', ['%label' => $this->entity->label()]));
    }

    $form_state->setRedirect('entity.cforge_neighbourhood.collection');
  }



}
